"""
Efficiency evaluation for different selections

Felix Metzner 2021
"""

import pandas as pd

from typing import Tuple, Dict, List

from rdstar.utilities import PathType

from rdstar.offline_analysis.mc_scaling_weights import MCSampleScaler
from rdstar.offline_analysis.observables.common_observables import Cols
from rdstar.offline_analysis.weight_management.weight_information import WeightTypeCollection
from rdstar.offline_analysis.efficiency_calculation.simple_efficiency_calculator import DataTypeFraction


__all__ = [
    "EfficiencyEvaluator",
]


class EfficiencyEvaluator:
    data_type_column_name: str = Cols.data_type
    decay_mode_column_name: str = Cols.decay_mode_column_name

    own_eff_weight_column_name: str = "tmp_eff_systematics_eval_weight"

    def __init__(
        self,
        sig_id_data_type_mapping: Dict[int, Tuple[DataTypeFraction, ...]],
        sig_id_column_name: str,
        file_dict_base_path: PathType,
    ) -> None:

        self._sig_id_column_name: str = sig_id_column_name
        self._sig_id_data_type_mapping: Dict[int, Tuple[DataTypeFraction, ...]] = sig_id_data_type_mapping
        self._file_dict_base_path: PathType = file_dict_base_path

        self._scale_weight_map: Dict[str, float] = MCSampleScaler.generate_data_type_scaling_map(
            file_dict_dir_path=self._file_dict_base_path
        )

    def calculate_for(self, df: pd.DataFrame) -> float:  # TODO: What output type should it be?
        pass

    def init_info_df(self, input_df: pd.DataFrame) -> pd.DataFrame:  # TODO!!!!
        used_cols: List[str] = [
            self._sig_id_column_name,
            self.data_type_column_name,
            self.decay_mode_column_name,
        ]
        eff_weight_cols: List[str] = list(WeightTypeCollection.efficiency_weight_columns)

        required_cols: List[str] = used_cols + eff_weight_cols
        assert all(c in input_df.columns for c in required_cols), [c for c in required_cols if c not in input_df.columns]

        df: pd.DataFrame = input_df.loc[:, required_cols].copy(deep=True)
        df.loc[:, self.own_eff_weight_column_name] = df[eff_weight_cols].product(axis=1)

        return df

    # TODO: For plots: https://seaborn.pydata.org/tutorial/distributions.html
