import os
import yaml
import click

from analysistools.batch_tools.file_handler import load_json_config
from analysistools.dataframe_tools.dataframe_tools import copy_online_analysis_output_from_remote

from rdstar.utilities import PathType
from rdstar.offline_analysis.tasks.utilities import get_config_dir_path_for


@click.command()
@click.option(
    "--config",
    "-c",
    "config_file",
    required=True,
    type=click.Path(exists=True),
    help="path to offline analysis config",
)
def copy_files_from_remote(config_file):
    """
    This script copies the files specified in the offline config from the kekcc.
    """
    with open(config_file) as f:
        offline_config = yaml.load(f, Loader=yaml.FullLoader)

    base_path = get_config_dir_path_for(production_tag=offline_config["production_tag"])  # type: PathType

    batch_configs = [load_json_config(os.path.join(base_path, c)) for c in offline_config["batch_configs"]]

    target_dir = offline_config["working_dir"]

    remote_host = offline_config["file_transfer"]["remote_host"]
    remote_src_dir = offline_config["file_transfer"]["remote_source_dir"]

    copy_online_analysis_output_from_remote(
        remote_host=remote_host,
        source_dir=remote_src_dir,
        target_dir=target_dir,
        configs=batch_configs,
    )
