import os
import pandas as pd

from rdstar.offline_analysis.fitting.dedicated_fit_approach.cont_cal_evaluation.cont_cal_eval_tools import (
    ContCalEvalResult,
)

__all__ = [
    "apply_continuum_calibration",
    "apply_continuum_calibration_for_dss_modes",
]


_cc_fit_scenario_name: str = "cont_cal_main"
_cc_for_dss_fit_scenario_name: str = "cont_cal_main_for_dss"

_cc_selection_name: str = "main_selection_with_right_sig_tag_comb"
_cc_fit_obs_setup_tag: str = "ContCalBChargeObsSetup1_cs_cos_tbto"

base_cont_cal_res_dir_path: str = "/home/fmetzner/Downloads/"
cc_eval_name: str = "ContCalEvaluation_05thJune2023"


def apply_continuum_calibration(df: pd.DataFrame) -> pd.DataFrame:
    _cc_file_name: str = f"{_cc_fit_scenario_name}__{_cc_selection_name}__{_cc_fit_obs_setup_tag}.json"
    _cc_file_path = os.path.join(base_cont_cal_res_dir_path, cc_eval_name, _cc_file_name)
    assert os.path.isfile(_cc_file_path), _cc_file_path

    cont_cal_corr_result = ContCalEvalResult.load_from_file(file_path=_cc_file_path)
    return cont_cal_corr_result.get_mc_sample_with_correction(
        df=df,
    )


def apply_continuum_calibration_for_dss_modes(df: pd.DataFrame) -> pd.DataFrame:
    _cc_for_dss_file_name: str = f"{_cc_for_dss_fit_scenario_name}__{_cc_selection_name}__{_cc_fit_obs_setup_tag}.json"
    _cc_for_dss_file_path = os.path.join(base_cont_cal_res_dir_path, cc_eval_name, _cc_for_dss_file_name)
    assert os.path.isfile(_cc_for_dss_file_path), _cc_for_dss_file_path

    cont_cal_corr_result = ContCalEvalResult.load_from_file(file_path=_cc_for_dss_file_path)
    return cont_cal_corr_result.get_mc_sample_with_correction(
        df=df,
    )
