"""
MC Matching SigIDs for extended mc matching information.

Felix Metzner 2023
"""

from templatefitter.plotter import plot_style

from rdstar.offline_analysis.reco_modes.reco_mode_infos import RecoModeInfos

from rdstar.offline_analysis.mc_matching.mc_matching_utilities import MCSigID
from rdstar.offline_analysis.mc_matching.abstract_mc_matching_info import AbstractBaseMCSigIDsClass

__all__ = [
    "MCSigIDs",
]


class MCSigIDs(AbstractBaseMCSigIDsClass):
    # IDs
    # Signal
    # fmt: off
    cB_to_nD_tau_via_e_nu: MCSigID = MCSigID(id=11, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_d_e_mode.id, color=plot_style.KITColors.kit_green)
    nB_to_cD_tau_via_e_nu: MCSigID = MCSigID(id=12, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_d_e_mode.id, color=plot_style.KITColors.kit_green)
    cB_to_nD_tau_via_mu_nu: MCSigID = MCSigID(id=13, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_d_mu_mode.id, color=plot_style.KITColors.kit_green)
    nB_to_cD_tau_via_mu_nu: MCSigID = MCSigID(id=14, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_d_mu_mode.id, color=plot_style.KITColors.kit_green)
    cB_to_nDst_tau_via_e_nu_with_Dst_to_pi: MCSigID = MCSigID(id=21, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_ds_e_mode.id, color=plot_style.KITColors.kit_maygreen)
    nB_to_cDst_tau_via_e_nu_with_Dst_to_pi: MCSigID = MCSigID(id=22, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_ds_e_mode.id, color=plot_style.KITColors.kit_maygreen)
    cB_to_nDst_tau_via_mu_nu_with_Dst_to_pi: MCSigID = MCSigID(id=23, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_ds_mu_mode.id, color=plot_style.KITColors.kit_maygreen)
    nB_to_cDst_tau_via_mu_nu_with_Dst_to_pi: MCSigID = MCSigID(id=24, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_ds_mu_mode.id, color=plot_style.KITColors.kit_maygreen)
    cB_to_nDst_tau_via_e_nu_with_Dst_to_photon: MCSigID = MCSigID(id=25, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_ds_e_mode.id, color=plot_style.KITColors.kit_maygreen)
    nB_to_cDst_tau_via_e_nu_with_Dst_to_photon: MCSigID = MCSigID(id=26, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_ds_e_mode.id, color=plot_style.KITColors.kit_maygreen)
    cB_to_nDst_tau_via_mu_nu_with_Dst_to_photon: MCSigID = MCSigID(id=27, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_ds_mu_mode.id, color=plot_style.KITColors.kit_maygreen)
    nB_to_cDst_tau_via_mu_nu_with_Dst_to_photon: MCSigID = MCSigID(id=28, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_ds_mu_mode.id, color=plot_style.KITColors.kit_maygreen)
    # Norm
    cB_to_nD_e_nu: MCSigID = MCSigID(id=31, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_d_e_mode.id, color=plot_style.KITColors.kit_blue)
    nB_to_cD_e_nu: MCSigID = MCSigID(id=32, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_d_e_mode.id, color=plot_style.KITColors.kit_blue)
    cB_to_nD_mu_nu: MCSigID = MCSigID(id=33, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_d_mu_mode.id, color=plot_style.KITColors.kit_blue)
    nB_to_cD_mu_nu: MCSigID = MCSigID(id=34, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_d_mu_mode.id, color=plot_style.KITColors.kit_blue)
    cB_to_nDst_e_nu_with_Dst_to_pi: MCSigID = MCSigID(id=41, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_ds_e_mode.ids, color=plot_style.KITColors.kit_cyan)
    nB_to_cDst_e_nu_with_Dst_to_pi: MCSigID = MCSigID(id=42, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_ds_e_mode.ids, color=plot_style.KITColors.kit_cyan)
    cB_to_nDst_e_nu_with_Dst_to_photon: MCSigID = MCSigID(id=45, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_ds_e_mode.ids, color=plot_style.KITColors.kit_cyan)
    nB_to_cDst_e_nu_with_Dst_to_photon: MCSigID = MCSigID(id=46, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_ds_e_mode.ids, color=plot_style.KITColors.kit_cyan)
    cB_to_nDst_mu_nu_with_Dst_to_pi: MCSigID = MCSigID(id=43, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_ds_mu_mode.ids, color=plot_style.KITColors.kit_cyan)
    nB_to_cDst_mu_nu_with_Dst_to_pi: MCSigID = MCSigID(id=44, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_ds_mu_mode.ids, color=plot_style.KITColors.kit_cyan)
    cB_to_nDst_mu_nu_with_Dst_to_photon: MCSigID = MCSigID(id=47, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_ds_mu_mode.ids, color=plot_style.KITColors.kit_cyan)
    nB_to_cDst_mu_nu_with_Dst_to_photon: MCSigID = MCSigID(id=48, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_ds_mu_mode.ids, color=plot_style.KITColors.kit_cyan)
    # D** with pi0
    cB_to_nDone_via_pi0_e_nu: MCSigID = MCSigID(id=511, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_e_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDtwostar_via_pi0_e_nu: MCSigID = MCSigID(id=512, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_e_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDzerostar_via_pi0_e_nu: MCSigID = MCSigID(id=513, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_e_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDprimeone_via_pi0_e_nu: MCSigID = MCSigID(id=514, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_e_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDone_via_pi0_e_nu: MCSigID = MCSigID(id=521, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_e_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDtwostar_via_pi0_e_nu: MCSigID = MCSigID(id=522, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_e_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDzerostar_via_pi0_e_nu: MCSigID = MCSigID(id=523, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_e_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDprimeone_via_pi0_e_nu: MCSigID = MCSigID(id=524, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_e_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDone_via_pi0_mu_nu: MCSigID = MCSigID(id=531, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_mu_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDtwostar_via_pi0_mu_nu: MCSigID = MCSigID(id=532, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_mu_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDzerostar_via_pi0_mu_nu: MCSigID = MCSigID(id=533, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_mu_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDprimeone_via_pi0_mu_nu: MCSigID = MCSigID(id=534, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_mu_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDone_via_pi0_mu_nu: MCSigID = MCSigID(id=541, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_mu_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDtwostar_via_pi0_mu_nu: MCSigID = MCSigID(id=542, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_mu_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDzerostar_via_pi0_mu_nu: MCSigID = MCSigID(id=543, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_mu_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDprimeone_via_pi0_mu_nu: MCSigID = MCSigID(id=544, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_mu_via_dwwos_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDone_via_pi0_tau_nu: MCSigID = MCSigID(id=551, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_l_via_d_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDtwostar_via_pi0_tau_nu: MCSigID = MCSigID(id=552, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_l_via_d_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDzerostar_via_pi0_tau_nu: MCSigID = MCSigID(id=553, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_l_via_d_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    cB_to_nDprimeone_via_pi0_tau_nu: MCSigID = MCSigID(id=554, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_l_via_d_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDone_via_pi0_tau_nu: MCSigID = MCSigID(id=561, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_l_via_d_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDtwostar_via_pi0_tau_nu: MCSigID = MCSigID(id=562, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_l_via_d_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDzerostar_via_pi0_tau_nu: MCSigID = MCSigID(id=563, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_l_via_d_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    nB_to_cDprimeone_via_pi0_tau_nu: MCSigID = MCSigID(id=564, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_l_via_d_pi0_modes.ids, color=plot_style.KITColors.kit_red)
    # D** with pi+
    cB_to_nDone_via_pip_e_nu: MCSigID = MCSigID(id=611, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_e_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDtwostar_via_pip_e_nu: MCSigID = MCSigID(id=612, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_e_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDzerostar_via_pip_e_nu: MCSigID = MCSigID(id=613, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_e_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDprimeone_via_pip_e_nu: MCSigID = MCSigID(id=614, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_e_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDone_via_pip_e_nu: MCSigID = MCSigID(id=621, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_e_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDtwostar_via_pip_e_nu: MCSigID = MCSigID(id=622, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_e_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDzerostar_via_pip_e_nu: MCSigID = MCSigID(id=623, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_e_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDprimeone_via_pip_e_nu: MCSigID = MCSigID(id=624, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_e_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDone_via_pip_mu_nu: MCSigID = MCSigID(id=631, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_mu_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDtwostar_via_pip_mu_nu: MCSigID = MCSigID(id=632, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_mu_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDzerostar_via_pip_mu_nu: MCSigID = MCSigID(id=633, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_mu_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDprimeone_via_pip_mu_nu: MCSigID = MCSigID(id=634, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_mu_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDone_via_pip_mu_nu: MCSigID = MCSigID(id=641, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_mu_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDtwostar_via_pip_mu_nu: MCSigID = MCSigID(id=642, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_mu_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDzerostar_via_pip_mu_nu: MCSigID = MCSigID(id=643, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_mu_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDprimeone_via_pip_mu_nu: MCSigID = MCSigID(id=644, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_mu_via_dwwos_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDone_via_pip_tau_nu: MCSigID = MCSigID(id=651, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_l_via_d_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDtwostar_via_pip_tau_nu: MCSigID = MCSigID(id=652, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_l_via_d_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDzerostar_via_pip_tau_nu: MCSigID = MCSigID(id=653, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_l_via_d_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    cB_to_nDprimeone_via_pip_tau_nu: MCSigID = MCSigID(id=654, expected_signal_in_decay_ids=RecoModeInfos.charged_b_to_dss_l_via_d_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDone_via_pip_tau_nu: MCSigID = MCSigID(id=661, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_l_via_d_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDtwostar_via_pip_tau_nu: MCSigID = MCSigID(id=662, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_l_via_d_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDzerostar_via_pip_tau_nu: MCSigID = MCSigID(id=663, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_l_via_d_pip_modes.ids, color=plot_style.KITColors.kit_orange)
    nB_to_cDprimeone_via_pip_tau_nu: MCSigID = MCSigID(id=664, expected_signal_in_decay_ids=RecoModeInfos.neutral_b_to_dss_l_via_d_pip_modes.ids, color=plot_style.KITColors.kit_orange)

    # BKGs
    # Hadronic tau BKG
    cB_to_nD_HADRONIC_tau_nu: MCSigID = MCSigID(id=711, expected_signal_in_decay_ids=None, color=plot_style.KITColors.kit_brown)
    nB_to_cD_HADRONIC_tau_nu: MCSigID = MCSigID(id=712, expected_signal_in_decay_ids=None, color=plot_style.KITColors.kit_brown)
    cB_to_nDst_HADRONIC_tau_nu: MCSigID = MCSigID(id=721, expected_signal_in_decay_ids=None, color=plot_style.KITColors.kit_brown)
    nB_to_cDst_HADRONIC_tau_nu: MCSigID = MCSigID(id=722, expected_signal_in_decay_ids=None, color=plot_style.KITColors.kit_brown)
    #
    cB_to_nDone_via_pi0_HADRONIC_tau_nu: MCSigID = MCSigID(id=751, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    cB_to_nDtwostar_via_pi0_HADRONIC_tau_nu: MCSigID = MCSigID(id=752, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    cB_to_nDzerostar_via_pi0_HADRONIC_tau_nu: MCSigID = MCSigID(id=753, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    cB_to_nDprimeone_via_pi0_HADRONIC_tau_nu: MCSigID = MCSigID(id=754, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    nB_to_cDone_via_pi0_HADRONIC_tau_nu: MCSigID = MCSigID(id=761, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    nB_to_cDtwostar_via_pi0_HADRONIC_tau_nu: MCSigID = MCSigID(id=762, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    nB_to_cDzerostar_via_pi0_HADRONIC_tau_nu: MCSigID = MCSigID(id=763, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    nB_to_cDprimeone_via_pi0_HADRONIC_tau_nu: MCSigID = MCSigID(id=764, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    cB_to_nDone_via_pip_HADRONIC_tau_nu: MCSigID = MCSigID(id=771, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    cB_to_nDtwostar_via_pip_HADRONIC_tau_nu: MCSigID = MCSigID(id=772, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    cB_to_nDzerostar_via_pip_HADRONIC_tau_nu: MCSigID = MCSigID(id=773, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    cB_to_nDprimeone_via_pip_HADRONIC_tau_nu: MCSigID = MCSigID(id=774, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    nB_to_cDone_via_pip_HADRONIC_tau_nu: MCSigID = MCSigID(id=781, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    nB_to_cDtwostar_via_pip_HADRONIC_tau_nu: MCSigID = MCSigID(id=782, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    nB_to_cDzerostar_via_pip_HADRONIC_tau_nu: MCSigID = MCSigID(id=783, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    nB_to_cDprimeone_via_pip_HADRONIC_tau_nu: MCSigID = MCSigID(id=784, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.chocolate1)
    #
    # Hadronic Background (HBKG) -> Reconstructed lepton is no lepton
    LeptonFake_HBKG: MCSigID = MCSigID(id=801, expected_signal_in_decay_ids=None, color=plot_style.KITColors.kit_purple)
    LeptonRecoFake_HBKG: MCSigID = MCSigID(id=802, expected_signal_in_decay_ids=None, color=plot_style.KITColors.kit_purple)
    # Generic Backgrounds
    DststMesonToThree_GBKG: MCSigID = MCSigID(id=811, expected_signal_in_decay_ids=None, color=plot_style.KITColors.dark_grey)
    LeptonWithoutBMesonRelation_GBKG: MCSigID = MCSigID(id=812, expected_signal_in_decay_ids=None, color=plot_style.KITColors.dark_grey)
    DMesonFake_GBKG: MCSigID = MCSigID(id=813, expected_signal_in_decay_ids=None, color=plot_style.KITColors.dark_grey)
    BtoDxxlxx_GBKG: MCSigID = MCSigID(id=814, expected_signal_in_decay_ids=None, color=plot_style.KITColors.dark_grey)
    LeptonFromOtherBDecay_GBKG: MCSigID = MCSigID(id=815, expected_signal_in_decay_ids=None, color=plot_style.KITColors.dark_grey)
    # B -> pi l nu
    NeutralPiLNu: MCSigID = MCSigID(id=821, expected_signal_in_decay_ids=RecoModeInfos.b_to_pi0_l_modes.ids, color=plot_style.KITColors.kit_yellow)
    ChargedPiLNu: MCSigID = MCSigID(id=822, expected_signal_in_decay_ids=RecoModeInfos.b_to_pip_l_modes.ids, color=plot_style.KITColors.kit_yellow)
    NeutralPiTauNu: MCSigID = MCSigID(id=823, expected_signal_in_decay_ids=RecoModeInfos.b_to_pi0_l_modes.ids, color=plot_style.KITColors.kit_yellow)
    ChargedPiTauNu: MCSigID = MCSigID(id=824, expected_signal_in_decay_ids=RecoModeInfos.b_to_pip_l_modes.ids, color=plot_style.KITColors.kit_yellow)
    # Mismatch G BKGs
    LeptonCrossFeed_Tau_EToMu_GBKG: MCSigID = MCSigID(id=831, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.plum1)
    LeptonCrossFeed_Tau_MuToE_GBKG: MCSigID = MCSigID(id=832, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.plum1)
    LeptonCrossFeed_EToMu_GBKG: MCSigID = MCSigID(id=833, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.plum1)
    LeptonCrossFeed_MuToE_GBKG: MCSigID = MCSigID(id=834, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.plum1)
    #
    DststDaughterMismatch_nB_cDss_e_GBKG: MCSigID = MCSigID(id=841, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_nB_cDss_mu_GBKG: MCSigID = MCSigID(id=842, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_nB_cDss_tau_GBKG: MCSigID = MCSigID(id=843, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_cB_cDss_e_GBKG: MCSigID = MCSigID(id=844, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_cB_cDss_mu_GBKG: MCSigID = MCSigID(id=845, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_cB_cDss_tau_GBKG: MCSigID = MCSigID(id=846, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_nB_nDss_e_GBKG: MCSigID = MCSigID(id=851, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_nB_nDss_mu_GBKG: MCSigID = MCSigID(id=852, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_nB_nDss_tau_GBKG: MCSigID = MCSigID(id=853, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_cB_nDss_e_GBKG: MCSigID = MCSigID(id=854, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_cB_nDss_mu_GBKG: MCSigID = MCSigID(id=855, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)
    DststDaughterMismatch_cB_nDss_tau_GBKG: MCSigID = MCSigID(id=856, expected_signal_in_decay_ids=None, color=plot_style.TangoColors.scarletred1)

    # Generic B decays (all the events not covered by any other query)
    GBKG: MCSigID = MCSigID(id=860, expected_signal_in_decay_ids=None, color=plot_style.KITColors.grey)

    # Continuum BKG
    Charm_CBKG: MCSigID = MCSigID(id=901, expected_signal_in_decay_ids=None, color=plot_style.KITColors.light_grey)
    UDS_CBKG: MCSigID = MCSigID(id=902, expected_signal_in_decay_ids=None, color=plot_style.KITColors.light_grey)

    # fmt: on


MCSigIDs.run_checks()


if __name__ == "__main__":
    for k, v in MCSigIDs.get_sig_ids_dict().items():
        print(f"{k}: {v}")

    print(MCSigIDs.get_all_sig_ids())
